@@ -2,10 +2,7 @@ use strict;
 use warnings;
 
 package HTTP::BrowserDetect;
-{
-  $HTTP::BrowserDetect::VERSION = '1.65';
-}
-
+$HTTP::BrowserDetect::VERSION = '1.68';
 use vars qw(@ALL_TESTS);
 
 # Operating Systems
@@ -90,6 +87,7 @@ our @IE_TESTS = qw(
     ie55up      ie6         ie7
     ie8         ie9         ie10
     ie11
+    ie_compat_mode
 );
 
 our @OPERA_TESTS = qw(
@@ -121,6 +119,7 @@ our @ENGINE_TESTS = qw(
 # https://support.google.com/webmasters/answer/1061943?hl=en
 
 my %ROBOTS = (
+    ahrefs         => 'Ahrefs',
     altavista      => 'AltaVista',
     askjeeves      => 'AskJeeves',
     baidu          => 'Baidu Spider',
@@ -152,6 +151,7 @@ my %ROBOTS = (
     webtv          => 'WebTV',
     wget           => 'wget',
     yahoo          => 'Yahoo',
+    yandex         => 'Yandex',
     yandeximages   => 'YandexImages',
 );
 
@@ -168,6 +168,7 @@ our @ROBOT_TESTS = qw(
     askjeeves    googleadsense googlebotvideo
     googlebotnews googlebotimage google
     linkchecker  yandeximages specialarchiver
+    yandex       ahrefs
 );
 
 our @MISC_TESTS = qw(
@@ -282,6 +283,10 @@ sub _test {
     # Trident Engine (detect early for sniffing out IE)
     $tests->{TRIDENT} = ( index( $ua, "trident/" ) != -1 );
 
+    if ( $tests->{TRIDENT} && $ua =~ /trident\/([\w\.\d]*)/ ) {
+        $self->{engine_version} = $1;
+    }
+
     # Browser version
     my ( $major, $minor, $beta ) = (
         $ua =~ m{
@@ -499,6 +504,11 @@ sub _test {
     $tests->{IE10} = ( $tests->{IE} && $major == 10 );
     $tests->{IE11} = ( $tests->{IE} && $major == 11 );
 
+    $tests->{IE_COMPAT_MODE}
+        = (    $tests->{IE7}
+            && $tests->{TRIDENT}
+            && $self->{engine_version} + 0 >= 4 );
+
     # Neoplanet browsers
 
     $tests->{NEOPLANET} = ( index( $ua, "neoplanet" ) != -1 );
@@ -633,6 +643,7 @@ sub _test {
             || ( index( $ua, "android" ) != -1
             && index( $ua, "mobile" ) == -1
             && index( $ua, "opera" ) == -1 )
+            || ($tests->{FIREFOX} && index( $ua, "tablet" ) != -1)
             || index( $ua, "kindle" ) != -1
             || index( $ua, "xoom" ) != -1
             || index( $ua, "flyer" ) != -1
@@ -674,17 +685,10 @@ sub _test {
     if ( $tests->{GECKO} ) {
         if ( $ua =~ /\([^)]*rv:([\w.\d]*)/ ) {
             $self->{gecko_version} = $1;
+            $self->{engine_version} = $1;
         }
     }
 
-    # Engines
-
-    $self->{engine_version} = $self->{gecko_version};
-
-    if ( $ua =~ /trident\/([\w\.\d]*)/ ) {
-        $self->{engine_version} = $1;
-    }
-
     # RealPlayer
     $tests->{REALPLAYER}
         = ( index( $ua, "(r1 " ) != -1 || index( $ua, "realplayer" ) != -1 );
@@ -754,6 +758,7 @@ sub _robot_tests {
         ) != -1
     );
 
+    $tests->{AHREFS}         = ( index( $ua, "ahrefsbot" ) != -1 );
     $tests->{ALTAVISTA}      = ( index( $ua, "altavista" ) != -1 );
     $tests->{ASKJEEVES}      = ( index( $ua, "ask jeeves/teoma" ) != -1 );
     $tests->{BAIDU}          = ( index( $ua, "baiduspider" ) != -1 );
@@ -777,10 +782,12 @@ sub _robot_tests {
     $tests->{SPECIALARCHIVER}          = ( index( $ua, "special_archiver" ) != -1 );
     $tests->{WEBCRAWLER}     = ( index( $ua, "webcrawler" ) != -1 );
     $tests->{WGET}           = ( index( $ua, "wget" ) != -1 );
+    $tests->{YANDEX}         = ( index( $ua, "yandexbot" ) != -1 );
     $tests->{YANDEXIMAGES}   = ( index( $ua, "yandeximages" ) != -1 );
 
     $tests->{ROBOT}
-        = (    $tests->{ALTAVISTA}
+        = (    $tests->{AHREFS}
+            || $tests->{ALTAVISTA}
             || $tests->{ASKJEEVES}
             || $tests->{BAIDU}
             || $tests->{FACEBOOK}
@@ -806,6 +813,7 @@ sub _robot_tests {
             || $tests->{WEBCRAWLER}
             || $tests->{WGET}
             || $tests->{YAHOO}
+            || $tests->{YANDEX}
             || $tests->{YANDEXIMAGES} )
         || index( $ua, "agent" ) != -1
         || index( $ua, "bot" ) != -1
@@ -984,7 +992,7 @@ sub _os_tests {
 
     $tests->{FIREFOXOS}
         = (    $tests->{FIREFOX}
-            && $tests->{MOBILE}
+            && ($tests->{MOBILE} || $tests->{TABLET})
             && !$tests->{ANDROID}
             && index( $ua, "fennec" ) == -1 );
 
@@ -1480,13 +1488,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 HTTP::BrowserDetect - Determine Web browser, version, and platform from an HTTP user agent string
 
 =head1 VERSION
 
-version 1.65
+version 1.68
 
 =head1 SYNOPSIS
 
@@ -1752,6 +1762,13 @@ version separately.
 
 =head3 ie ie3 ie4 ie4up ie5 ie55 ie6 ie7 ie8 ie9 ie10 ie11
 
+=head3 ie_compat_mode
+
+The ie_compat_mode is used to determine if the IE user agent is for
+the compatibility mode view, in which case the real version of IE is
+higher than that detected. The true version of IE can be inferred from
+the version of Trident in the engine_version method.
+
 =head3 java
 
 =head3 konqueror
@@ -1864,6 +1881,8 @@ automated Web client.
 The following additional methods are available, each returning a true or false
 value. This is by no means a complete list of robots that exist on the Web.
 
+=head3 ahrefs
+
 =head3 altavista
 
 =head3 askjeeves
@@ -1902,6 +1921,10 @@ value. This is by no means a complete list of robots that exist on the Web.
 
 =head3 yahoo
 
+=head3 yandex
+
+=head3 yandeximages
+
 =head1 CREDITS
 
 Lee Semel, lee@semel.net (Original Author)
@@ -1992,6 +2015,8 @@ David Ihnen
 
 Hao Wu
 
+Perlover
+
 =head1 TO DO
 
 The C<_engine()> method currently only handles Gecko and Trident.  It needs to
